@@ -3,12 +3,11 @@ use std::{
 	ops::{Deref, DerefMut},
 };
 
-use crate::NamedSliceSerializer;
-
 /// Stores named bound query arguments
 ///
 /// This `struct` stores data for passing as argument slice to `*_named()` query functions of rusqlite.
 /// To get the instance call crate's `to_named_params()` function.
+#[derive(Default)]
 pub struct NamedParamSlice(Vec<(String, Box<dyn rusqlite::types::ToSql>)>);
 
 impl NamedParamSlice {
@@ -23,12 +22,6 @@ impl From<Vec<(String, Box<dyn rusqlite::types::ToSql>)>> for NamedParamSlice {
 	}
 }
 
-impl From<NamedSliceSerializer> for NamedParamSlice {
-	fn from(src: NamedSliceSerializer) -> Self {
-		src.0
-	}
-}
-
 impl Deref for NamedParamSlice {
 	type Target = Vec<(String, Box<dyn rusqlite::types::ToSql>)>;
 
